/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { Body_Workflow_create_workflow } from '../models/Body_Workflow_create_workflow';
import type { Body_Workflow_update_workflow } from '../models/Body_Workflow_update_workflow';
import type { Status } from '../models/Status';
import type { WorkflowOut } from '../models/WorkflowOut';
import type { WorkflowVersionFull } from '../models/WorkflowVersionFull';
import type { WorkflowVersionStatus } from '../models/WorkflowVersionStatus';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class WorkflowService {

    /**
     * List workflows
     * List all workflows.
     *
     * Permission "workflow:list" required.
     * @param nameSubstring Filter workflows by a substring in their name.
     * @param versionStatus Which versions of the workflow to include in the response. Permission 'workflow:list_filter required'. Default PUBLISHED and DEPRECATED.
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowListWorkflows(
        nameSubstring?: string,
        versionStatus?: Array<Status>,
    ): CancelablePromise<Array<WorkflowOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows',
            query: {
                'name_substring': nameSubstring,
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Create a new workflow
     * Create a new workflow.
     *
     * Permission "workflow:create" required.
     * @param formData
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowCreateWorkflow(
        formData: Body_Workflow_create_workflow,
    ): CancelablePromise<WorkflowOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/workflows',
            formData: formData,
            mediaType: 'multipart/form-data',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a workflow
     * Get a specific workflow.
     *
     * Permission "workflow: read" required.
     * @param wid ID of a workflow
     * @param versionStatus Which versions of the workflow to include in the response. Permission 'workflow:read_any' required if you are not the developer of this workflow. Default PUBLISHED and DEPRECATED
     * @returns WorkflowOut Successful Response
     * @throws ApiError
     */
    public static workflowGetWorkflow(
        wid: string,
        versionStatus?: Array<Status>,
    ): CancelablePromise<WorkflowOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}',
            path: {
                'wid': wid,
            },
            query: {
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Delete a workflow
     * Delete a workflow.
     *
     * Permission "workflow:delete" required.
     * @param wid ID of a workflow
     * @returns void
     * @throws ApiError
     */
    public static workflowDeleteWorkflow(
        wid: string,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/workflows/{wid}',
            path: {
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Update a workflow
     * Create a new workflow version.
     *
     * Permission "workflow:update" required.
     * @param wid ID of a workflow
     * @param formData
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowUpdateWorkflow(
        wid: string,
        formData: Body_Workflow_update_workflow,
    ): CancelablePromise<WorkflowVersionFull> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/workflows/{wid}/update',
            path: {
                'wid': wid,
            },
            formData: formData,
            mediaType: 'multipart/form-data',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get all versions of a workflow
     * List all versions of a Workflow.
     *
     * Permission "workflow:list" required.
     * @param wid ID of a workflow
     * @param versionStatus Which versions of the workflow to include in the response. Permission 'workflow:list_filter' required if you are not the developer of this workflow. Default PUBLISHED and DEPRECATED
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionListWorkflowVersion(
        wid: string,
        versionStatus?: Array<Status>,
    ): CancelablePromise<Array<WorkflowVersionFull>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/versions',
            path: {
                'wid': wid,
            },
            query: {
                'version_status': versionStatus,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a workflow version
     * Get a specific version of a workflow.
     *
     * Permission "workflow:read" required if the version is public or you are the developer of the workflow,
     * otherwise "workflow:read_any"
     * @param gitCommitHash Git commit git_commit_hash of specific version or 'latest'.
     * @param wid ID of a workflow
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionGetWorkflowVersion(
        gitCommitHash: string,
        wid: string,
    ): CancelablePromise<WorkflowVersionFull> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/workflows/{wid}/versions/{git_commit_hash}',
            path: {
                'git_commit_hash': gitCommitHash,
                'wid': wid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Update status of workflow version
     * Update the status of a workflow version.
     *
     * Permission "workflow:update_status"
     * @param gitCommitHash Git commit git_commit_hash of specific version.
     * @param wid ID of a workflow
     * @param requestBody
     * @returns WorkflowVersionFull Successful Response
     * @throws ApiError
     */
    public static workflowVersionUpdateWorkflowVersionStatus(
        gitCommitHash: string,
        wid: string,
        requestBody: WorkflowVersionStatus,
    ): CancelablePromise<WorkflowVersionFull> {
        return __request(OpenAPI, {
            method: 'PATCH',
            url: '/workflows/{wid}/versions/{git_commit_hash}/status',
            path: {
                'git_commit_hash': gitCommitHash,
                'wid': wid,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
